summaryrefslogtreecommitdiffstats
path: root/color/quoted.c
diff options
context:
space:
mode:
Diffstat (limited to 'color/quoted.c')
-rw-r--r--color/quoted.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/color/quoted.c b/color/quoted.c
index 135e28f8d..ce14f6847 100644
--- a/color/quoted.c
+++ b/color/quoted.c
@@ -612,10 +612,10 @@ static void qstyle_recurse(struct QuoteStyle *quote_list, int num_qlevel, int *c
}
/**
* qstyle_recolour - Recolour quotes after colour changes
* @param quote_list List of quote colours
*/
-void qstyle_recolour(struct QuoteStyle *quote_list)
+void qstyle_recolor(struct QuoteStyle *quote_list)
{
if (!quote_list)
return;
@@ -612,10 +612,10 @@ static void qstyle_recurse(struct QuoteStyle *quote_list, int num_qlevel, int *c
}
/**
- * qstyle_recolour - Recolour quotes after colour changes
+ * qstyle_recolor - Recolour quotes after colour changes
* @param quote_list List of quote colours
*/